@@ -1,3 +1,2 @@
-Name = "PythonMeta"
-Version = 0.90
+name = "PythonMeta"
 from .core import Help, Data, Meta, Fig
\ No newline at end of file
